HH = 'HH'
VV = 'VV'
VV_VH = 'VV+VH'
HH_HV = 'HH+HV'
DUAL_HH = ''
DUAL_VV = ''
DUAL_HV = ''
DUAL_VH = ''
HH_3SCAN = ''
HH_4SCAN = ''
HH_5SCAN = ''
QUAD = 'quadrature'
HH_VV = 'HH+VV'
HH_HV_VH_VV = 'HH+HV+VH+VV'
FULL = 'full'
UNKNOWN = 'UNKNOWN'