HOST = 'api.daac.asf.alaska.edu'
HOST_TEST = 'api-test.asf.alaska.edu'
HOST_DEV = 'api-dev.asf.alaska.edu'
HOST_LOCAL = 'local.asf.alaska.edu:5000'

HEALTH_PATH = '/health'
SEARCH_PATH = '/services/search/param'
BASELINE_PATH = '/services/search/baseline'
MISSION_PATH = '/services/utils/mission_list'
DATE_PATH = '/services/utils/date'

CMR_HOST = 'cmr.earthdata.nasa.gov'
CMR_HOST_UAT = 'cmr.uat.earthdata.nasa.gov'
